var keys_8h =
[
    [ "PW_KEY_ACCESS", "keys_8h.html#ad1bfca30c613b28723527132429bb342", null ],
    [ "PW_KEY_APP_ICON", "keys_8h.html#a91ffcff4f7a88575416d6aecbcff12e4", null ],
    [ "PW_KEY_APP_ICON_NAME", "keys_8h.html#a4e2766cf97b0c413b31daffd06194fb8", null ],
    [ "PW_KEY_APP_ID", "keys_8h.html#a7e7975fdc1d4879492d18bd5737fc7d7", null ],
    [ "PW_KEY_APP_LANGUAGE", "keys_8h.html#a1a435b1fed956236009f28357f69a11c", null ],
    [ "PW_KEY_APP_NAME", "keys_8h.html#a56fa277cca24072d0208f0ada2e8af02", null ],
    [ "PW_KEY_APP_PROCESS_BINARY", "keys_8h.html#a21aeba14e1488c5133af73d8857f2c4b", null ],
    [ "PW_KEY_APP_PROCESS_HOST", "keys_8h.html#a10b428d9bce530cad8fd247157ae2dc0", null ],
    [ "PW_KEY_APP_PROCESS_ID", "keys_8h.html#aad182b8b5d38fc6083d15b2c43e00e83", null ],
    [ "PW_KEY_APP_PROCESS_MACHINE_ID", "keys_8h.html#a1c5aadbbcd440e874a9b86c4ebd3445f", null ],
    [ "PW_KEY_APP_PROCESS_SESSION_ID", "keys_8h.html#aedf51309856ddd63ceb49dd66f047f30", null ],
    [ "PW_KEY_APP_PROCESS_USER", "keys_8h.html#a6ce71220f1c5262d51adfcc8b9648b69", null ],
    [ "PW_KEY_APP_VERSION", "keys_8h.html#aba46167b2135bb7862a8c92b6a8066ab", null ],
    [ "PW_KEY_AUDIO_CHANNEL", "keys_8h.html#ad1330d4bd54022740c64b1b7b0cc357e", null ],
    [ "PW_KEY_AUDIO_CHANNELS", "keys_8h.html#a7f63a5688e90b4d78e8db0c7a18bd959", null ],
    [ "PW_KEY_AUDIO_FORMAT", "keys_8h.html#a0b13a2631ffb67076f67105d1ca347d6", null ],
    [ "PW_KEY_AUDIO_RATE", "keys_8h.html#af4643e961de004488943e2ab0322ac4c", null ],
    [ "PW_KEY_CLIENT_ACCESS", "keys_8h.html#a550a0954601e7bf139955115f4b1c030", null ],
    [ "PW_KEY_CLIENT_API", "keys_8h.html#ad38809401a347afdefdefc12b9066e10", null ],
    [ "PW_KEY_CLIENT_ID", "keys_8h.html#a40cda23f85c981d1fc72e452f0972c0b", null ],
    [ "PW_KEY_CLIENT_NAME", "keys_8h.html#a53bbec2813b8e4f108d1d50596e0669b", null ],
    [ "PW_KEY_CONTEXT_PROFILE_MODULES", "keys_8h.html#a2b3f6a3b030fd27d17482e601c22be3b", null ],
    [ "PW_KEY_CORE_DAEMON", "keys_8h.html#a8226b0005fed53b77740e919947f6e60", null ],
    [ "PW_KEY_CORE_ID", "keys_8h.html#a01502d8ebbf130bdc9bdbc847da9202a", null ],
    [ "PW_KEY_CORE_MONITORS", "keys_8h.html#a1fcadd4d03343c8f5737c00f4900404e", null ],
    [ "PW_KEY_CORE_NAME", "keys_8h.html#a7d8bfd1e173bfbb0360b7a59bd2ec68a", null ],
    [ "PW_KEY_CORE_VERSION", "keys_8h.html#adaf914599e9ddeab31f925204323f678", null ],
    [ "PW_KEY_CPU_CORES", "keys_8h.html#aa11bdd266a759598aaab9aac3c6f2a3a", null ],
    [ "PW_KEY_CPU_MAX_ALIGN", "keys_8h.html#a06b47804dd060e946c700c96ba46aa22", null ],
    [ "PW_KEY_DEVICE_API", "keys_8h.html#a1ae6cfa4f3af67155c58f5f0398e8c56", null ],
    [ "PW_KEY_DEVICE_BUS", "keys_8h.html#ac1cc4afb3e028b4d00231d615705adce", null ],
    [ "PW_KEY_DEVICE_BUS_PATH", "keys_8h.html#ad853c0be569ab7bc329486573016a600", null ],
    [ "PW_KEY_DEVICE_CLASS", "keys_8h.html#a4790b6248f443648211d05573db3ac77", null ],
    [ "PW_KEY_DEVICE_DESCRIPTION", "keys_8h.html#a66aff2e97b93c3b4c029de74f0233373", null ],
    [ "PW_KEY_DEVICE_FORM_FACTOR", "keys_8h.html#a2ce5cc947b2519113b1d96b4f599eae3", null ],
    [ "PW_KEY_DEVICE_ICON", "keys_8h.html#ae735cebef63f5368aec0d1859890c5cb", null ],
    [ "PW_KEY_DEVICE_ICON_NAME", "keys_8h.html#a2a53446671230c87420a0edd859e70c4", null ],
    [ "PW_KEY_DEVICE_ID", "keys_8h.html#a0b1f97dbee8170ef4b6e972fac51dd73", null ],
    [ "PW_KEY_DEVICE_INTENDED_ROLES", "keys_8h.html#ada09ee1ffbf8eb6eaf8bb5f0431fbccf", null ],
    [ "PW_KEY_DEVICE_NAME", "keys_8h.html#a3815f163f7283a2d979daf59acb204e2", null ],
    [ "PW_KEY_DEVICE_NICK", "keys_8h.html#afe595c32416d6f09ff02ceb3d91517fe", null ],
    [ "PW_KEY_DEVICE_PLUGGED", "keys_8h.html#a0f5e212dc11f074ea26ec962050242d9", null ],
    [ "PW_KEY_DEVICE_PRODUCT_ID", "keys_8h.html#a4e33abd756479b380e6413a54ce66d9c", null ],
    [ "PW_KEY_DEVICE_PRODUCT_NAME", "keys_8h.html#a02187c666af78ce29dc10af967233709", null ],
    [ "PW_KEY_DEVICE_SERIAL", "keys_8h.html#a355da8fad4633bc22ddac10620451672", null ],
    [ "PW_KEY_DEVICE_STRING", "keys_8h.html#adeb9ac2f463b5163d363a13a03c9dde1", null ],
    [ "PW_KEY_DEVICE_SUBSYSTEM", "keys_8h.html#aae4d17260ca60c2ab5e2c8d32b989d67", null ],
    [ "PW_KEY_DEVICE_VENDOR_ID", "keys_8h.html#ab0c9eba65b9611e85e0304b49f58739e", null ],
    [ "PW_KEY_DEVICE_VENDOR_NAME", "keys_8h.html#aee10eee4b6b4dc090110939e78adbc10", null ],
    [ "PW_KEY_FACTORY_ID", "keys_8h.html#a57e4e4edbcaf5d9420a24f033cf48f3d", null ],
    [ "PW_KEY_FACTORY_NAME", "keys_8h.html#a574c03c1c69ee214f3ef156903226bac", null ],
    [ "PW_KEY_FACTORY_TYPE_NAME", "keys_8h.html#a2094ae2785d311a4b58da7357ec257ed", null ],
    [ "PW_KEY_FACTORY_TYPE_VERSION", "keys_8h.html#a897eec1867a8fc40db2526f7fed9b2db", null ],
    [ "PW_KEY_FACTORY_USAGE", "keys_8h.html#ab63750b3248313ac7ca19b93feedeb9b", null ],
    [ "PW_KEY_FORMAT_DSP", "keys_8h.html#aecb23469e678c55d7c0f3b6ebe180abb", null ],
    [ "PW_KEY_HOST_NAME", "keys_8h.html#a9530cacf53a11083543fc8b0076d8b4b", null ],
    [ "PW_KEY_LIBRARY_NAME_DBUS", "keys_8h.html#a32748e803174c4983e3f5378fcbe0e87", null ],
    [ "PW_KEY_LIBRARY_NAME_LOOP", "keys_8h.html#a62381a633016e0f980878eaa018ef429", null ],
    [ "PW_KEY_LIBRARY_NAME_SYSTEM", "keys_8h.html#ada76163a82aae28e7563c6c28eddc5ea", null ],
    [ "PW_KEY_LINK_ID", "keys_8h.html#a2adca834d1bf86f9bb4c3d52af9460e8", null ],
    [ "PW_KEY_LINK_INPUT_NODE", "keys_8h.html#a8bcf374cc8d1cf2c23060479d484c4c8", null ],
    [ "PW_KEY_LINK_INPUT_PORT", "keys_8h.html#ae327718323a22392d489db85ad83ab8f", null ],
    [ "PW_KEY_LINK_OUTPUT_NODE", "keys_8h.html#aaa5cf742d2c5bfee35f18392ddc3ca9e", null ],
    [ "PW_KEY_LINK_OUTPUT_PORT", "keys_8h.html#a4976c4bc1a9d0119617d02fae557e108", null ],
    [ "PW_KEY_LINK_PASSIVE", "keys_8h.html#afcd3d133168b9353c89c1c5f2de6954e", null ],
    [ "PW_KEY_MEDIA_ARTIST", "keys_8h.html#a5239e21cdcdd48b4dc147305df1cb742", null ],
    [ "PW_KEY_MEDIA_CATEGORY", "keys_8h.html#ad58dc457d6b068c7ae086b6792824404", null ],
    [ "PW_KEY_MEDIA_CLASS", "keys_8h.html#aed255c860a65813289cb4c4620243da6", null ],
    [ "PW_KEY_MEDIA_COMMENT", "keys_8h.html#ae0e0edc267b24e27054f72f899cb2123", null ],
    [ "PW_KEY_MEDIA_COPYRIGHT", "keys_8h.html#a377a7240f82837f1c861976faf4240af", null ],
    [ "PW_KEY_MEDIA_DATE", "keys_8h.html#a920ad1d3f16b5fe42e001aab2af08680", null ],
    [ "PW_KEY_MEDIA_FILENAME", "keys_8h.html#a0823daaf814cb12aca70c024f76eaf0b", null ],
    [ "PW_KEY_MEDIA_FORMAT", "keys_8h.html#a5fcd76f87ed122633f0a90ac05aae123", null ],
    [ "PW_KEY_MEDIA_ICON", "keys_8h.html#a49cb5fe34980f268f7bb844f54de72f5", null ],
    [ "PW_KEY_MEDIA_ICON_NAME", "keys_8h.html#ad7fe1ca68b65df33c09b8d14cfd708b0", null ],
    [ "PW_KEY_MEDIA_LANGUAGE", "keys_8h.html#a308a6720f63b611d74666c4dfc6dbe7d", null ],
    [ "PW_KEY_MEDIA_NAME", "keys_8h.html#ac8cc358cf31f66cde84ed87a9a2fb2e7", null ],
    [ "PW_KEY_MEDIA_ROLE", "keys_8h.html#a7e7dcf769f9e253b0e3cde6534feed69", null ],
    [ "PW_KEY_MEDIA_SOFTWARE", "keys_8h.html#a6cceecd3d45dc787cddaefc7c3c5de53", null ],
    [ "PW_KEY_MEDIA_TITLE", "keys_8h.html#a6d930a117ae86e23154fbfdcca42cab8", null ],
    [ "PW_KEY_MEDIA_TYPE", "keys_8h.html#a1bb5e1cae8d27cc995923266024c0ed5", null ],
    [ "PW_KEY_MODULE_AUTHOR", "keys_8h.html#a7b74eb5c78b28b8346df16e7d66487d1", null ],
    [ "PW_KEY_MODULE_DESCRIPTION", "keys_8h.html#abfbbb750dca1b2cbd8aef676e6f3b1f3", null ],
    [ "PW_KEY_MODULE_ID", "keys_8h.html#abe4f427fb9ecb27d29c2567243ce18e7", null ],
    [ "PW_KEY_MODULE_NAME", "keys_8h.html#ab36a79eff93ca96a84fc38c7aedb4ecf", null ],
    [ "PW_KEY_MODULE_USAGE", "keys_8h.html#a06f0aa2f06667a7596322689acf3b1b7", null ],
    [ "PW_KEY_MODULE_VERSION", "keys_8h.html#a18a9e0e59cd1a02e6c444edae293f887", null ],
    [ "PW_KEY_NODE_ALWAYS_PROCESS", "keys_8h.html#a832d4e7fcc412f53aea49186c6ff2c8b", null ],
    [ "PW_KEY_NODE_AUTOCONNECT", "keys_8h.html#a677b0938b4f1d2d52326c64b4b90eb8e", null ],
    [ "PW_KEY_NODE_DESCRIPTION", "keys_8h.html#a4d4e1af1a950aafe7b4184a89fa4e016", null ],
    [ "PW_KEY_NODE_DONT_RECONNECT", "keys_8h.html#a02774290763120baf89042785522c0c2", null ],
    [ "PW_KEY_NODE_DRIVER", "keys_8h.html#ac760a7d13f161fcc86e964ad23399180", null ],
    [ "PW_KEY_NODE_EXCLUSIVE", "keys_8h.html#acc9bbcbe9fc948df2fec4592640cd39c", null ],
    [ "PW_KEY_NODE_GROUP", "keys_8h.html#a5b8ea75d1a6f9a1d0d0e60e60eeae5a8", null ],
    [ "PW_KEY_NODE_ID", "keys_8h.html#af3bf787a5d2b9e035d3ddfdfe848d810", null ],
    [ "PW_KEY_NODE_LATENCY", "keys_8h.html#a6d08c36bb4d3bcae49e822023a8089e2", null ],
    [ "PW_KEY_NODE_NAME", "keys_8h.html#aaa6e55cb44dbfe8af1a9e8531abe6f09", null ],
    [ "PW_KEY_NODE_NICK", "keys_8h.html#ab54f33c6bfc0125599328b198ae81d06", null ],
    [ "PW_KEY_NODE_PAUSE_ON_IDLE", "keys_8h.html#a0fb0fbf1691bb6972434b61706c3217a", null ],
    [ "PW_KEY_NODE_PLUGGED", "keys_8h.html#a36edd8da67e859b5b7c6ab425f4f9e49", null ],
    [ "PW_KEY_NODE_SESSION", "keys_8h.html#a457ecf62c9dcb4a1f5719bc74fbb0183", null ],
    [ "PW_KEY_NODE_STREAM", "keys_8h.html#a8ff654b149404ba9e46f02e376cf9dcc", null ],
    [ "PW_KEY_NODE_TARGET", "keys_8h.html#a33441b02b8e14e14451272c2b497a5c9", null ],
    [ "PW_KEY_OBJECT_ID", "keys_8h.html#aaa13a0c747a64ff4f80c68f383e6f479", null ],
    [ "PW_KEY_OBJECT_LINGER", "keys_8h.html#a3d5bd6f00b3c9a8d89e42aa6c3f8cb58", null ],
    [ "PW_KEY_OBJECT_PATH", "keys_8h.html#af7bfe4ca43d361fe707d51c4b4590423", null ],
    [ "PW_KEY_PORT_ALIAS", "keys_8h.html#afa03a2ea34407e692ddc35bb1f200c59", null ],
    [ "PW_KEY_PORT_CONTROL", "keys_8h.html#af8e40c7f0a99f019f9b3b8187b96f8b0", null ],
    [ "PW_KEY_PORT_DIRECTION", "keys_8h.html#a4a25213dfcf1d7b7ded06ed9284f1a5f", null ],
    [ "PW_KEY_PORT_ID", "keys_8h.html#a94975808271e28be225a6fd6d7957762", null ],
    [ "PW_KEY_PORT_MONITOR", "keys_8h.html#a52f311c1f1005fda30a47a3b5fc19a77", null ],
    [ "PW_KEY_PORT_NAME", "keys_8h.html#a086fc9bb9864325037b0bd2310816034", null ],
    [ "PW_KEY_PORT_PHYSICAL", "keys_8h.html#a42bac0319021f95809991bf90ff5f1c5", null ],
    [ "PW_KEY_PORT_TERMINAL", "keys_8h.html#a53f5727e8c728c0398320b5191bb934c", null ],
    [ "PW_KEY_PRIORITY_DRIVER", "keys_8h.html#af0a8b16bba9dde55e5b8ba018b4b5ceb", null ],
    [ "PW_KEY_PRIORITY_SESSION", "keys_8h.html#aeb72e3878b35a65f02163535ad274408", null ],
    [ "PW_KEY_PROTOCOL", "keys_8h.html#a75a6c78ce2de6d3dc5ed23abecdbc3bd", null ],
    [ "PW_KEY_REMOTE_INTENTION", "keys_8h.html#aff405f056c4afbeb87df6f663178b993", null ],
    [ "PW_KEY_REMOTE_NAME", "keys_8h.html#a86dd4aa9894e3d6deb9570988e37f6ca", null ],
    [ "PW_KEY_SEC_GID", "keys_8h.html#a6abeb07b483a60e05f60224f7a5aae34", null ],
    [ "PW_KEY_SEC_LABEL", "keys_8h.html#a9cde0fd069af370dd80ad3deac5ee053", null ],
    [ "PW_KEY_SEC_PID", "keys_8h.html#a3273f4c970bf0c85f1eb220d368ea444", null ],
    [ "PW_KEY_SEC_UID", "keys_8h.html#ad6000734888b498669ad7aebcee155eb", null ],
    [ "PW_KEY_STREAM_CAPTURE_SINK", "keys_8h.html#a1ac41df86c2b03ef693864d48d80f735", null ],
    [ "PW_KEY_STREAM_DONT_REMIX", "keys_8h.html#a79843e403121d8dda275d869c770d3f2", null ],
    [ "PW_KEY_STREAM_IS_LIVE", "keys_8h.html#afc94345e17e428e4816adf8eb0bcb993", null ],
    [ "PW_KEY_STREAM_LATENCY_MAX", "keys_8h.html#a2d0601eb11704dc85da950b5188a4ad3", null ],
    [ "PW_KEY_STREAM_LATENCY_MIN", "keys_8h.html#a91d57a3b42dc55028dd49755716db901", null ],
    [ "PW_KEY_STREAM_MONITOR", "keys_8h.html#a0e1b45ffe5365ae023676fab61f53764", null ],
    [ "PW_KEY_USER_NAME", "keys_8h.html#a42bba61b82c004dd909c1796633e936b", null ],
    [ "PW_KEY_VIDEO_FORMAT", "keys_8h.html#a38e8da2c19e9cd1acf5823865f6e9742", null ],
    [ "PW_KEY_VIDEO_RATE", "keys_8h.html#ac353c9d9c3ed50ea98806f63f09f9456", null ],
    [ "PW_KEY_VIDEO_SIZE", "keys_8h.html#acc4d098e86d0be0bfe469604c07f4009", null ],
    [ "PW_KEY_WINDOW_X11_DISPLAY", "keys_8h.html#ac21702d9ef1b7b6772303f4681e854a1", null ]
];